@@ -188,6 +188,19 @@ def _run_m4_and_append(schema, maddir_mod_py, module, sqlfile,
                   '-DMODULE_NAME=' + module,
                   '-I' + maddir_madpack,
                   sqlfile]
+        if ( (portid == 'postgres') &
+             (is_rev_gte(get_rev_num(dbver), get_rev_num('14.0'))) ):
+            m4args = ['m4',
+                  '-P',
+                  '-DMADLIB_SCHEMA=' + schema,
+                  '-DPLPYTHON_LIBDIR=' + maddir_mod_py,
+                  '-DEXT_PYTHON_LIBDIR=' + maddir_ext_py,
+                  '-DMODULE_PATHNAME=' + maddir_lib,
+                  '-DMADLIB_LIBRARY_PATH=' + madlib_library_path,
+                  '-DMODULE_NAME=' + module,
+                  '-DUSE_COMPATIBLE_ARRAY=TRUE',
+                  '-I' + maddir_madpack,
+                  sqlfile]
 
         info_(this, "> ... parsing: " + " ".join(m4args), verbose)
         output_filehandle.flush()
@@ -1226,16 +1239,17 @@ def create_install_madlib_sqlfile(args, madpack_cmd):
 
 def get_madlib_function_drop_str(schema):
 
-    if portid == 'greenplum':
+    if ((portid == 'greenplum' and is_rev_gte(get_rev_num(dbver), get_rev_num('7.0'))) or
+        (portid == 'postgres')):
         case_str = """
-        CASE
-          WHEN p.proisagg THEN 'aggregate'
+        CASE p.prokind
+          WHEN 'a' THEN 'aggregate'
           ELSE 'function'
           """
     else:
         case_str = """
-        CASE p.prokind
-          WHEN 'a' THEN 'aggregate'
+        CASE
+          WHEN p.proisagg THEN 'aggregate'
           ELSE 'function'
           """
     madlib_functions = _internal_run_query("""
@@ -1320,11 +1334,18 @@ def set_dynamic_library_path_in_database(dbver_split, madlib_library_path):
 
     global dynamic_library_path
     dynamic_library_path = _internal_run_query("SHOW dynamic_library_path", True)[0]['dynamic_library_path']
-    # GP7 gpconfig messes up $libdir so we remove it for now
+    # GP7 gpconfig messes up $libdir so we put the actual path
     paths = dynamic_library_path.split(":")
     if madlib_library_path not in paths:
         if '$libdir' in paths:
             paths.remove('$libdir')
+            libdir = subprocess.check_output(['pg_config','--libdir'])
+            if ((portid == 'greenplum' and is_rev_gte(dbver_split, get_rev_num('7.0'))) or
+                (portid == 'postgres' and is_rev_gte(dbver_split, get_rev_num('13.0')))):
+                libdir = libdir.decode()
+
+            libdir = libdir.strip()+'/postgresql'
+            paths.append(libdir)
 
         paths.append(madlib_library_path)
         dynamic_library_path = ':'.join(paths)
